@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: All.h 2106 2006-11-26 12:54:41Z svn $
+ * $Id: All.h 2153 2006-12-02 09:15:38Z svn $
  *****************************************************************************/
 
 #ifndef ALL_H
@@ -44,10 +44,11 @@
 #include "Message.h"
 #include "MessageDigest5.h"
 #include "MmapFileWriter.h"
+#include "MultipartMessageParser.h"
+#include "MultipartMessageParserBuffer.h"
 #include "PostDataChecker.h"
 #include "PostFlowController.h"
 #include "RFC1867Parser.h"
-#include "RFC1867ParserBuffer.h"
 #include "ReadLocker.h"
 #include "ReadWriteLocker.h"
 #include "SourceInfo.h"
