@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemManager.h 2273 2006-12-17 13:35:43Z svn $
+ * $Id: UploadItemManager.h 2296 2006-12-24 02:58:57Z svn $
  *****************************************************************************/
 
 #ifndef UPLOAD_ITEM_MANAGER_H
@@ -38,7 +38,6 @@
 
 #include "Uncopyable.h"
 
-using namespace std;
 
 class UploadItemList;
 class ThumbnailList;
@@ -68,7 +67,7 @@ public:
     UploadItem *get_item(apr_pool_t *pool, apr_size_t item_id);
     apr_file_t *get_item_file(apr_pool_t *pool, apr_size_t item_id,
                               bool is_sendfile_enabled=false);
-    apr_time_t get_mtime() const throw()
+    apr_time_t get_mtime() const
     {
         return *mtime_;
     };
